* SPSS 16.0 for Windows, Release 16.0.1 .
* Diese Datei: E:\bsn\Workshop_06_2008\SPSS-Beispiele\beispiel5.sps (25.02.2009) .
set length none.
set width 132.
set header no.
set mxwarns=5.  

* CD '<Arbeitsverzeichnis>'.

* ========================================================================.
* Beispiel 5: Gesamtwerte mit gebundener Hochrechnung (Poststratifikation).
*                 SPSS bietet keine Schtzung fr Poststratifikation      .
*                 => Anwendung der Stata-Formeln fr Poststratifikation   . 
* ========================================================================.

* Quelle: 
  Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
  Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
  File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
       http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
       sp-fehler/SPSS_Beispiele.zip .

get file = "mz02cf_Beisp.sav"
            /keep ef1 ef3 ef30 ef32 ef52 ef127 ef504 ef505 ef712 ef750g.
DATASET NAME DataSet1 WINDOW=FRONT.

missing values all().
compute id = $casenum.

* Variablenabgenzungen analog zu Beispiel 1.
compute schicht = ef1*10 + ef712.
compute f = 0.01 * 0.035.
compute w = 1/f.
compute sub = (ef505<=2 & ef30>=15).
compute y = (ef504=2) * sub.
formats y sub (f1.0).

* Vorbereitung Poststratifikation.
* 1a) Anpassung: Geschl. * Staatsangeh., Sold., Wehrpfl.
* compute anp=0.
do if (ef52=1 & ef32=1 & ef127<>9 & ef127<>10).
compute anp=1.
else if (ef52=1 & ef32=2).
compute anp=2.
else if (ef52<>1 & ef32=1).
compute anp=3.
else if (ef52<>1 & ef32=2).
compute anp=4.
else if (ef52=1 & ef32=1 & ef127=9).
compute anp=5.
else if (ef52=1 & ef32=1 & ef127=10).
compute anp=6.
end if.
variable label anp 'Anpassungsklasse'.
value label anp
  1 'Deutsche Maenner'                  2 'Deutsche Frauen'
  3 'Auslaendische Maenner'             4 'Auslaendische Frauen'
  5 'Zeit-/Berufssold., BGS, Ber.pol.'  6 'Grundwehrdienstleistende'.
formats anp (f1).
* 1b) Proxy Anpassungsschicht .
compute anpschicht=sub*(ef1*10+anp).
formats anpschicht (f4).

* 2)  Populationsdaten pro Anpassungsschicht.
compute w_anp = ef750g*100*(ef505<=2).
compute wsub = w*sub.
recode w_anp wsub (sysmis=0).
aggregate outfile = * mode=addvariables
       /break anpschicht
       /M_k = sum(w_anp)
       /M_Dach_k = sum(wsub).
recode M_k M_Dach_k (sysmis=0).
sort cases by id.

* 3) Umsetzung der Stata-Formeln .
compute w_post = M_k/M_Dach_k*w .
do if (sub=0).
compute w_post = 0.
end if.
compute y_post = w_post * y.
recode y_post (sysmis=0).
* Gesamtwert y_post: poststratifiziert .

* V(Y_post) fr Hilfsmerkmal (score variable) z.
compute wysub = w*y*sub.
recode wysub (sysmis=0).
aggregate outfile = * mode=addvariables
       /break anpschicht
       /Y_Dach_k = sum(wysub).
recode Y_Dach_k (sysmis=0).
sort cases by id.

compute z = sub*(M_k/M_Dach_k) * (y - (Y_Dach_k/M_Dach_k)).
recode z (sysmis=0).

CSPLAN ANALYSIS
  /PLAN FILE='beispiel5_At.csaplan'
  /PLANVARS ANALYSISWEIGHT=w_post
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel5_At.csaplan'
 /SUMMARY VARIABLES =y
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS COUNT .

* Schtzung des Standardfehlers.
* --> Total irrelevant <---. 
CSPLAN ANALYSIS
  /PLAN FILE='beispiel5_Ase.csaplan'
  /PLANVARS ANALYSISWEIGHT=w
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel5_Ase.csaplan'
 /SUMMARY VARIABLES =z
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS SE .

temporary.
select if (sub=1).
compute w750g=ef750g*100.
weight by w750g.
fre y.

* --------------------------------------------------------------------------- .
* Problem:  Gesamtwert der gebundenen Hochrechnung (t = 3.428.499) stimmt     .
* nicht mit gewichteter Tabellierung (t = 3.431.212) berein, da sich die     .
* Hochrechnungsfaktoren insgesamt bzw. der Subpopulation von den              .
* Hochrechnungsfaktoren fr y unterscheiden.                                  .
* Lsung: Direkte Verwendung des Hochrechnungsgewichts fr y und bertragung  .
* der Hochrechnungsfaktoren von y auch auf die Sub-/Population.               .
* --------------------------------------------------------------------------- .
compute wy = ef750g*0.035*y.
recode wy (sysmis=0).
aggregate outfile = * mode=addvariables
       /break anpschicht
       /wy_k = sum(wy)
      /ny_k = sum(y).
recode wy_k ny_k (sysmis=0).
sort cases by id.
compute g_y = wy_k / ny_k. 
recode g_y (sysmis=0).
* Endgewicht = Korrekturfaktor * Designgewicht .
compute w_y = g_y * w.
recode w_y (sysmis=0).
aggregate outfile = * mode=addvariables
       /break anpschicht
       /M_k2 = sum(w_y).
sort cases by id.

* Hilfsvariable fr Varianzschtzung.
compute z2 = sub*(M_k2/M_Dach_k) * (y - (Y_Dach_k/M_Dach_k)).
recode z2 (sysmis=0).
CSPLAN ANALYSIS
  /PLAN FILE='beispiel5_Bt.csaplan'
  /PLANVARS ANALYSISWEIGHT=w_y
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel5_Bt.csaplan'
 /SUMMARY VARIABLES =y
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS COUNT .
* Schtzung des Standardfehlers.
* --> Total irrelevant <---. 
CSPLAN ANALYSIS
  /PLAN FILE='beispiel5_Bse.csaplan'
  /PLANVARS ANALYSISWEIGHT=w
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel5_Bse.csaplan'
 /SUMMARY VARIABLES =z2
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM
 /STATISTICS SE .
