* SPSS 16.0 for Windows, Release 16.0.1 .
* Diese Datei: beispiel8.sps (02.03.2009) .
set length none.
set width 132.
set header no.
set mxwarns=5.  

* CD '<Arbeitsverzeichnis>'.

* ========================================================================.
* Beispiel 8: Erwerbslosenquote mit gebundener Hochrechnung               .
*             (Poststratifikation)                                        .
* ========================================================================.

* Quelle: 
  Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
  Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
  File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
       http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
       sp-fehler/SPSS_Beispiele.zip .

get file = "mz02cf_Beisp.sav"
   /keep ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef708 ef712 ef750g.
DATASET NAME DataSet1 WINDOW=FRONT.

missing values all().
compute id = $casenum.

* Variablenabgenzungen analog zu Beispiel 1.
compute schicht = ef1*10 + ef712.
* Auswahlsatz MZ 1%, CF 3,5% .
compute f = 0.01 * 0.035.
* Designgewicht.
compute w = 1/f .

* Subpopulation: Bevlkerung am Hauptwohnsitz, 15-65 Jahre, Erwerbspersonen.
compute sub = (ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2).

* Vorbereitung Poststratifikation.
* 1a) Anpassung: Geschl. * Staatsangeh., Sold., Wehrpfl.
* compute anp=0.
do if (ef52=1 & ef32=1 & ef127<>9 & ef127<>10). 
compute anp=1.
else if (ef52=1 & ef32=2) .
compute anp=2.
else if (ef52<>1 & ef32=1).
compute anp=3.
else if (ef52<>1 & ef32=2).
compute anp=4.
else if (ef52=1 & ef32=1 & ef127=9).
compute anp=5.
else if (ef52=1 & ef32=1 & ef127=10).
compute anp=6.
end if.
variable label anp 'Anpassungsklasse'.
value label anp
  1 'Deutsche Maenner'                  2 'Deutsche Frauen'
  3 'Auslaendische Maenner'             4 'Auslaendische Frauen'
  5 'Zeit-/Berufssold., BGS, Ber.pol.'  6 'Grundwehrdienstleistende'.
formats anp (f1).
* 1b) Proxy Anpassungsschicht (ohne Bercksichtigung der Subpopulation).
* compute anpschicht=(ef1*10+anp).
* TEST: anpschicht MIT sub.
compute anpschicht=(ef1*10+anp) * sub.
formats anpschicht (f4).

* ===================================================================== .
* SPSS Complex Samples bietet kein Verfahren fr gebundene Hochrechnung .
* (Poststratifikation)                                                  .
* Alternative: Umsetzung der Formeln in:                                .
* Bihler, Wolf, 2008: Parameterschtzungen aus den anonymisierten       .
*    Mikrozensus-Files (II): Gebundene Hochrechnung. ZUMA-Workshop      .
*    "Stichprobendesign und Hochrechnungsverfahren  im Mikrozensus",    .
*    12.-13. Juni 2008. [Folie 10]                                      .
* Anteil-/Verhltniswert:             R = t_y / t_z                     .
* Anpassungsfaktor:                 c_k = N_g / N_Dach_g                .
* Hilfsgren fr Varianzschtzung:  u_k = c_k * (v_k - v_sg)           .
*                                    v_k = 1/t_z * (y_k - R*z_k)        .
* Stichprobenmittel v_k in Anpassungsklasse g: v_quer_sg                .
* Beachte: Das Verfahren muss fr jede Subpopulation jeweils extra      .
* durchgefhrt werden                                                   .
* Im folgenden Beispiel wird nicht nach Region und Altersgruppe         .
* differenziert                                                         .
* Zum Vergleich mit Stata: svy linearized, subpop(sub) : ratio (y/x)    .
* Stata-Ergebnisse: Ratio = 0,0865867  Std. Err. = 0,0027175            .
* ===================================================================== .

* 2) Berechnung des Anpassungsfaktors.
* "Soll": Bevlkerung am Hauptwohnsitz, geb. Hochrechnung.
compute ng = ef750g*100*(ef505<=2).
* "Ist":  Bevlkerung am Hauptwohnsitz, Designgewichtung.
compute ndachg = (1/(0.01*0.035)*(ef505<=2)) .
sort cases by anpschicht.
aggregate outfile = * mode=addvariables
       /break anpschicht
       /N_g = sum(ng)
       /N_Dach_g = sum(ndachg).
* Anpassungsfaktor ohne Designgewichtung.
compute c_k = N_g / N_Dach_g.

sort cases by id.

* Zhlermerkmal: ILO-Erwerbslose & Subpopulation.
compute y = (ef504=2) * sub.
compute wy  = (ef504=2) * sub * ef750g * 100.
variable label y "ILO-Erwerbslose".
variable label wy "ILO-Erwerbslose - gewichtet (ef750g*100)".

* Nennermerkmal: Erwerbspersonen & Subpopulation.
compute z = (ef504>=1 & ef504<=2) * sub.
compute wz  = (ef504>=1 & ef504<=2) * sub * ef750g * 100.
variable label z "Erwerbspersonen".
variable label wz "Erwerbspersonen - gewichtet (ef750g*100)".

* Gesamtwerte Zhler- und Nennermerkmal bei gebundener Hochrechnung.
sort cases by id.
compute insg=1.
aggregate outfile = * mode=addvariables
       /break insg
       /ty = sum(wy)
       /tz = sum(wz).

* Anteils-/Verhltniswert bei gebundener Hochrechnung: Erwerbslosenquote.
compute R_yz = ty/tz.
* Gebundene Hochrechnung Ratio ==> S.E. irrelevant <== .
* temporary.
* means tables = R_yz by sub /cells=mean.

* Hilfsvariablen fr die Varianzschtzung.
compute v_k = 1/tz * (y - R_yz * z).
* Stichprobenmittel v_k in Anpassungsklasse g: v_quer_sg .
sort cases by anpschicht.
aggregate outfile = * mode=addvariables
       /break anpschicht
       /v_sg = mean(v_k).

sort cases by id.
* Hilfsvariable fr Varianzschtzung.
compute u_k = c_k * (v_k - v_sg).

* Stichprobendesign: SRSWR, Designgewichtung, Schichtung, Klumpung .
CSPLAN ANALYSIS
  /PLAN FILE='beispiel8.csaplan'
  /PLANVARS ANALYSISWEIGHT=w
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' STRATA=schicht CLUSTER=ef3 
  /ESTIMATOR TYPE=EQUAL_WOR
  /INCLPROB VARIABLE=f.

* Erwerbslosenquote Insgesamt .
CSDESCRIPTIVES
  /PLAN FILE='beispiel8.csaplan'
  /RATIO NUMERATOR=wy DENOMINATOR=wz
  /STATISTICS COUNT
  /SUBPOP TABLE=sub DISPLAY=LAYERED
  /MISSING SCOPE=ANALYSIS CLASSMISSING=EXCLUDE.
* SPSS-Ergebnis: Ratio = 0,086565 .
CSDESCRIPTIVES
 /PLAN FILE = 'beispiel8.csaplan'
 /SUMMARY VARIABLES = u_k
 /SUBPOP TABLE = sub  DISPLAY=LAYERED
 /SUM 
 /STATISTICS SE .
* SPSS-Ergebnis: Standardfehler = 0,002718.
