* SPSS 16.0 for Windows, Release 16.0.1 .
* Diese Datei: beispiel11.sps (02.03.2009) .
set length none.
set width 132.
set header no.
set mxwarns=5.  

* CD '<Arbeitsverzeichnis>'.

* =========================================================================.
* Beispiel 11: Regression des Monatsnettoeinkommens auf Bildung, Geschlecht.
*              und Staatsangehrigkeit                                     .
* =========================================================================.

* Quelle: 
  Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
  Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
  File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
       http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
       sp-fehler/SPSS_Beispiele.zip .

get file = "mz02cf_Beisp.sav"
   /keep = ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef286 ef287 ef288 ef289 
           ef338 ef372 ef504 ef505 ef708 ef712 ef750g.
DATASET NAME DataSet1 WINDOW=FRONT.

missing values all().
compute id = $casenum.

* Allgemeiner Bildungsabschluss - typische Ausbildungsdauer.
recode ef287 (1=9)      /* Hauptschule */
             (2 3=10)   /* Realschule, POS */
             (4=12)     /* FHR */
             (5=13)     /* Abitur */
             (0=8)      /* ohne Abschluss */
             (9=sysmis) /* k.A., Entfllt */
       into x287.
do if ((ef286=0 | ef286=9)).
recode x287 (else=sysmis).
end if.

* Beruflicher Abschluss - typische Ausbildungsdauer .
recode ef289 (0=0)         /* ohne Abschluss */
             (1 2=1)       /* Anlernausb., BVJ */
             (3 7 8=3)     /* Lehre, FH, Verw.FH */
             (4 5 6=2)     /* BFS, Meister, FS DDR */
             (9=5)         /* Uni */
             (10=7)        /* Prom. */
             (0 99=sysmis) /* k.A., Entfllt */
    into x289.
do if (ef288=0 | ef288=9).
recode x289 (else=sysmis).
end if.

* Rekodierung Nettoeinkommen - Klassenmitte bzw. 
*   obere Randklasse  = 150% * Untergrenze .
recode ef372 (1=75) (2=225) (3=400) (4=600) (5=800) (6=1000) (7=1200)
  (8=1400) (9=1600) (10=1850) (11=2150) (12=2450) (13=2750) (14=3050)
  (15=3400) (16=3800) (17=4250) (18=4750) (19=5250) (20=5750) 
  (21=6750) (22=8750) (23=14000) (24=27000) (50 90 99 = sysmis)
 into v372m.
compute logv372m = ln(v372m).

* Geschlecht.
recode ef32 (1=0) (2=1) into v32.
value labels v32 0 'mnnlich' 1 'weiblich'.
formats v32 (f1.0).

* Staatsangehrigkeit .
recode ef52 (1=0)    /* Deutsch */
            (else=1) /* Auslnder */
   into v52.

* Subpopulation . 
if (ef505>=1 & ef505<=2 &        /* Bevlkerung am Hauptwohnsitz */
    ef127>=4 & ef127<=6 &        /* Abh. Beschftigte (ohne Azubis) */
    ef504=1 &                    /* Erwerbsttige */ 
    ef338=1 &                    /* berw. Lebensunterhalt = Erwerbsttigk. */ 
    ef372>=1 & ef372<=24 &       /* gltige Einkommensangaben */
    x287>=8 & x287<=13 &         /* "       Angaben allg. Bildungsabschluss */
    x289>=0 & x289<=7)           /* "       Angaben berufl. Abschluss */
  sub=1.
recode sub (0 sysmis=0) (1=1).

* (1) OLS (SRSWR) .
REGRESSION
  /SELECT=sub EQ 1
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT logv372m
  /METHOD=ENTER x287 x289 v32 v52.

* (2) Robuste Varianzschtzung, Klumpung: Auswahlbezirk (SRSWR).
compute f = 0.01 * 0.035.
compute w = 1/f.
CSPLAN ANALYSIS
  /PLAN FILE='beispiel11.csaplan'
  /PLANVARS ANALYSISWEIGHT=w
  /SRSESTIMATOR TYPE=WR
  /PRINT PLAN
  /DESIGN STAGELABEL='PSU' CLUSTER=ef3
  /ESTIMATOR TYPE=WR.
temporary.
select if (sub=1).
CSGLM  logv372m WITH x287 x289 v32 v52 
  /PLAN FILE='beispiel11.csaplan' 
  /STATISTICS PARAMETER SE DEFF 
  /PRINT SUMMARY SAMPLEINFO 
  /TEST TYPE=ADJF PADJUST=LSD 
  /MISSING CLASSMISSING=EXCLUDE 
  /CRITERIA CILEVEL=95.
